﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

using System.Threading;
using System.IO;
using System.Diagnostics; 

namespace testDocX2Html
{
    public partial class FrmUseDocX2Html : Form
    {
        const string XSLT_FILE_DEFAULT = "DocX2HtmlWithImg.xslt"; //"DocX2Html.xslt";

        bool bInitExtractImages = global::testDocX2Html.Properties.Settings.Default.extractImages;      

        string appPath
        {
            get { return AppDomain.CurrentDomain.BaseDirectory; }
        }

        string getResourceStringByName(string resName)
        {
            return global::testDocX2Html.Properties.Resources.ResourceManager.GetString(resName, 
                Thread.CurrentThread.CurrentCulture);
        }

        public FrmUseDocX2Html()
        {
            InitializeComponent();

            string xsltFile = appPath + XSLT_FILE_DEFAULT;
            if (System.IO.File.Exists(xsltFile))
            {
                txtFileXSLT.Text = xsltFile; 
            }
            CheckEnabledRun();
        }

        protected override void OnClosing(CancelEventArgs e)
        {
            base.OnClosing(e);
            if (bInitExtractImages != global::testDocX2Html.Properties.Settings.Default.extractImages)
            {
                global::testDocX2Html.Properties.Settings.Default.Save();  
            }
        }

        private void btnClose_Click(object sender, EventArgs e)
        {
            Close(); 
        }

        private void btnRun_Click(object sender, EventArgs e)
        {
            btnRun.Enabled = false;
            Cursor = Cursors.WaitCursor;   
            Application.DoEvents();
            try
            {
                if (String.IsNullOrEmpty(txtFileXSLT.Text))
                {
                    throw new ArgumentNullException("txtFileXSLT.Text");
                }
                if (String.IsNullOrEmpty(txtFileDocx.Text))
                {
                    throw new ArgumentNullException("txtFileDocx.Text");
                }

                // Convert docx to html-string
                string outputFolder;
                string htmlContent;
                string error;
                ConvertDocX2Html.GetHtmlData(
                    txtFileDocx.Text, 
                    txtFileXSLT.Text,
                    chkImages.Checked,
                    out outputFolder,
                    out htmlContent, 
                    out error);
                if (!String.IsNullOrEmpty(error))
                {
                    MessageBox.Show(this, error, getResourceStringByName("errorCaption"),
                        MessageBoxButtons.OK, MessageBoxIcon.Error);
                }

                // Save & show result
                if (!String.IsNullOrEmpty(htmlContent))
                {
                    string htmlFile = txtFileDocx.Text;
                    int nPos = htmlFile.LastIndexOf('.');
                    if (nPos != (-1))
                    {
                        htmlFile = htmlFile.Substring(0, nPos) + ".htm";
                        if ((nPos = htmlFile.LastIndexOf('\\')) != (-1))
                        {
                            htmlFile = outputFolder + htmlFile.Substring(nPos);
                        }
                        else
                        {
                            htmlFile = outputFolder + htmlFile;
                        }
                        if (File.Exists(htmlFile))
                        {
                            File.Delete(htmlFile);
                        }
                        using (StreamWriter sw = new StreamWriter(htmlFile, false, Encoding.UTF8))
                        {
                            sw.Write(htmlContent);
                            sw.Flush();
                            sw.Close();
                        }
                        if (File.Exists(htmlFile))
                        {
                            System.Diagnostics.Process.Start("IExplore.exe", htmlFile);
                        }
                    }
                    else
                    {
                        throw new ArgumentException(htmlFile); 
                    }
                }
            }
            catch (Exception ex)
            {
                MessageBox.Show(this, ex.ToString(), getResourceStringByName("errorCaption"), 
                    MessageBoxButtons.OK, MessageBoxIcon.Error);         
            }
            btnRun.Enabled = true;
            Cursor = Cursors.Default;
        }

        private void btnSelectXslt_Click(object sender, EventArgs e)
        {
            openFileDlg.InitialDirectory = appPath;
            string filterXSLTValue = getResourceStringByName("filterXSLT");
            if (!String.IsNullOrEmpty(filterXSLTValue))
            {
                openFileDlg.Filter = filterXSLTValue;
            }
            openFileDlg.FileName = XSLT_FILE_DEFAULT;
            if (openFileDlg.ShowDialog(this) == DialogResult.OK)
            {
                txtFileXSLT.Text = openFileDlg.FileName;
                CheckEnabledRun();
            }
        }

        private void btnSelectDocx_Click(object sender, EventArgs e)
        {
            openFileDlg.InitialDirectory = Environment.GetFolderPath(Environment.SpecialFolder.Personal);
            string filterDOCXValue = getResourceStringByName("filterDOCX");
            if (!String.IsNullOrEmpty(filterDOCXValue))
            {
                openFileDlg.Filter = filterDOCXValue;
            }
            openFileDlg.FileName = "*.docx";
            if (openFileDlg.ShowDialog(this) == DialogResult.OK)
            {
                txtFileDocx.Text = openFileDlg.FileName;
                CheckEnabledRun();
            }
        }

        private void txtFileXSLT_TextChanged(object sender, EventArgs e)
        {
            CheckEnabledRun();
        }

        private void txtFileDocx_TextChanged(object sender, EventArgs e)
        {
            CheckEnabledRun();
        }

        void CheckEnabledRun()
        {
            btnRun.Enabled = (txtFileDocx.Text.Trim().Length > 0 && txtFileXSLT.Text.Trim().Length > 0);
        }
    }
}
